==> plotoptix-0.1.3.tar.gz: plotoptix-0.1.3/plotoptix/__init__.py <==
"""
3D raytracing package for Python. Based on NVIDIA OptiX framework,
and RnD.SharpOptiX C#/C++/CUDA libraries by R&D Team.

Copyright (C) 2019 R&D Team. All Rights Reserved.

Have a look at examples on GitHub: https://github.com/rnd-team-dev/plotoptix.
"""

from plotoptix.enums import *
from plotoptix.npoptix import NpOptiX
from plotoptix.tkoptix import TkOptiX

__all__ = ["enums", "materials", "utils", "npoptix", "tkoptix"]

__author__  = "Robert Sulej, R&D Team <dev@rnd.team>"
__status__  = "beta"
__version__ = "0.1.3"
__date__    = "16 April 2019"


import os, subprocess, logging

logging.basicConfig(level=logging.WARN, format='[%(levelname)s] (%(threadName)-10s) %(message)s')

# verify CUDA_PATH is defined ############################################
try:
    _cuda_path = os.environ["CUDA_PATH"]
except KeyError:
    logging.error(80 * "*"); logging.error(80 * "*")
    logging.error("CUDA_PATH environment variable not defined. Please check your CUDA installation.")
    logging.error(80 * "*"); logging.error(80 * "*")
    raise ImportError

# verify CUDA release ####################################################
_rel_required = "10.1"
try:
    _outp = subprocess.check_output(["nvcc", "--version"]).decode("utf-8").split(" ")
    try:
        _idx = _outp.index("release")
        if _idx + 1 < len(_outp):
            _rel = _outp[_idx + 1].strip(" ,")
            if _rel.startswith(_rel_required):
                logging.info("OK: found CUDA %s", _rel)
            else:
                logging.error(80 * "*"); logging.error(80 * "*")
                logging.error("Found CUDA release %s. This PlotOptiX release requires CUDA %s,", _rel, _rel_required)
                logging.error("available at: https://developer.nvidia.com/cuda-downloads")
                logging.error(80 * "*"); logging.error(80 * "*")
                raise ImportError
        else: raise ValueError
    except:
        logging.error(80 * "*"); logging.error(80 * "*")
        logging.error("CUDA release not recognized. This PlotOptiX release requires CUDA %s,", _rel_required)
        logging.error("available at: https://developer.nvidia.com/cuda-downloads")
        logging.error(80 * "*"); logging.error(80 * "*")
        raise ImportError

except FileNotFoundError:
    logging.error(80 * "*"); logging.error(80 * "*")
    logging.error("Cannot access nvcc. Please check your CUDA installation.")
    logging.error("This PlotOptiX release requires CUDA %s, available at:", _rel_required)
    logging.error("     https://developer.nvidia.com/cuda-downloads")
    logging.error(80 * "*"); logging.error(80 * "*")
    raise ImportError

except ImportError: raise ImportError

except Exception as e:
    logging.error("Cannot verify CUDA installation: " + str(e))
    raise ImportError

# check PlotOptiX updates ################################################
import json
import urllib.request
from packaging import version

try:
    url = "https://pypi.python.org/pypi/plotoptix/json"
    webURL = urllib.request.urlopen(url)
    data = webURL.read()
    encoding = webURL.info().get_content_charset('utf-8')
    data_dict = json.loads(data.decode(encoding))
    versions = list(data_dict["releases"].keys())
    versions.sort(key=version.parse)

    if version.parse(__version__) < version.parse(versions[-1]):
        print(80 * "*")
        print("PlotOptiX newer version is available:", versions[-1])
        print("to update your release use:")
        print("      pip install plotoptix --upgrade")
        print(80 * "*")

except: pass

==> plotoptix-0.11.1.tar.gz: plotoptix-0.11.1/plotoptix/__init__.py <==
"""
3D ray tracing package for Python. Based on NVIDIA OptiX 7 framework,
wrapped in RnD.SharpOptiX C#/C++/CUDA libraries by R&D Team.

https://github.com/rnd-team-dev/plotoptix/blob/master/LICENSE.txt

Have a look at examples on GitHub: https://github.com/rnd-team-dev/plotoptix.
Documentation: https://plotoptix.rnd.team
"""

__all__ = ["enums", "materials", "utils", "npoptix", "tkoptix"]

__author__  = "Robert Sulej, R&D Team <dev@rnd.team>"
__status__  = "beta"
__version__ = "0.11.1"
__date__    = "21 October 2020"

import logging

logging.basicConfig(level=logging.WARN, format='[%(levelname)s] (%(threadName)-10s) %(message)s')

# import PlotOptiX modules ###############################################
from plotoptix.enums import *
from plotoptix.npoptix import NpOptiX
from plotoptix.tkoptix import TkOptiX

# check PlotOptiX updates ################################################
import json
import urllib.request
from packaging import version

try:
    url = "https://pypi.python.org/pypi/plotoptix/json"
    webURL = urllib.request.urlopen(url, timeout=3)
    data = webURL.read()
    encoding = webURL.info().get_content_charset('utf-8')
    data_dict = json.loads(data.decode(encoding))
    versions = list(data_dict["releases"].keys())
    versions.sort(key=version.parse)

    if version.parse(__version__) < version.parse(versions[-1]):
        print(80 * "*")
        print("PlotOptiX newer version is available:", versions[-1])
        print("to update your release use:")
        print("      pip install plotoptix --upgrade")
        print(80 * "*")

except: pass
